SLACtrac
========

SLACtrac is designed to simulate linac elements, connected together,
to provide transfer matrices and beam propagation.

SLACtrac borrows significantly from ANL software Elegant:

http://www.aps.anl.gov/Accelerator_Systems_Division/Accelerator_Operations_Physics/software.shtml#elegant

Documentation
-------------

More in-depth documentation can be found at:

http://slactrac.readthedocs.org
